@@ -6,7 +6,7 @@ use exact;
 use Role::Tiny ();
 use Scalar::Util ();
 
-our $VERSION = '1.06'; # VERSION
+our $VERSION = '1.07'; # VERSION
 
 my ( $store, $roles );
 
@@ -150,7 +150,8 @@ sub ____attrs {
                         return $self;
                     }
                     else {
-                        return ( ref $self->{$name} eq 'CODE' ) ? $self->{$name}->($self) : $self->{$name};
+                        $self->{$name} = $self->{$name}->($self) if ( ref $self->{$name} eq 'CODE' );
+                        return $self->{$name};
                     }
                 }
                 : sub {
@@ -161,9 +162,11 @@ sub ____attrs {
                         return $self;
                     }
                     else {
-                        return ( ref $store->{ $set->{caller} }->{value}{$name} eq 'CODE' )
-                            ? $store->{ $set->{caller} }->{value}{$name}->($self)
-                            : $store->{ $set->{caller} }->{value}{$name};
+                        $store->{ $set->{caller} }->{value}{$name} =
+                            $store->{ $set->{caller} }->{value}{$name}->($self)
+                            if ( ref $store->{ $set->{caller} }->{value}{$name} eq 'CODE' );
+
+                        return $store->{ $set->{caller} }->{value}{$name};
                     }
                 };
 
@@ -221,7 +224,7 @@ exact::class - Simple class interface extension for exact
 
 =head1 VERSION
 
-version 1.06
+version 1.07
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/exact-class.svg)](https://travis-ci.org/gryphonshafer/exact-class)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/exact-class/badge.png)](https://coveralls.io/r/gryphonshafer/exact-class)
